*************************************************************************
* Copyright 2012, Pericom Semiconductor Corporation			* 
* All Rights Reserved							*
* CONFIDENTIAL INFORMATION - 						*
* Pericom Semiconductor Corporation PROPRIETARY				*
*************************************************************************

* PI3EQX7741Ai REDRIVER SIMULATION.
* TX -- differential signal input;
* RX -- differential output signal after redriver
* for all control settings, please refer to the datasheet; 

* Redriver diff. inputs at VIP & VIN
* Redriver diff. outputs at VOP & VON

*************************************************************************
* Simulation options and Library					*
*************************************************************************
.option post captab method=gear probe
.option gmindc=1e-13 gshdc=1e-13 runlvl=6

* Simulation Models
.inc 'header'

.temp 90
*************************************************************************
* Power Supplies and Controls						*
*************************************************************************
.param power3p3 = 3.3
vavdd	vdd3p3 0	power3p3
vagnd	agnd 0		0

********************************
* De-emphasis settings
* rdeup 	rdedn		DE
*  1e9		1e-3		0dB
*  1e9		1e9		-3.5dB
*  1e-3		1e9		6dB
********************************
rdeUP	vdd3p3 de 	rdeup
rdeDN	de 0		rdedn

********************************
* Equalizer settings
* requp		reqdn		EQ
*  1e9		1e-3		3dB
*  1e9		1e9		6dB
*  1e-3		1e9		9dB
********************************
reqUP	vdd3p3 eq	requp
reqDN	eq 0		reqdn

*************************************************************************
* Diffential Signal Input, PRBS2^7 pattern				*
*************************************************************************
.inc 'prbs7.inc'
rfil	in inx	10
cfil	inx 0	1.6p
ginp	0 tpp1	inx 0	'0.5/50' 
ginn	0 tpn1	inx 0	'-0.5/50'

rsrcp	tpp1 0		50
rsrcn	tpn1 0		50
*************************************************************************
* Input channel T-line; length = 3 inches                              *
*************************************************************************
wlp1 N=1 tpp1 0 tpp2 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'
wln1 N=1 tpn1 0 tpn2 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'

*************************************************************************
* External Input AC coupling                                            *
*************************************************************************
crxp    tpp2 vip	100n
crxn    tpn2 vin	100n

*************************************************************************
* Redriver PI3EQX7741Ai							*
* netlist.up calls subckt Redriver					*
*************************************************************************
.inc 'netlist.up'

*************************************************************************
* Output AC coupling							*
*************************************************************************
ctxp	vop tpp3	100n
ctxn	von tpn3	100n

*************************************************************************
* Output channel T-line; length = 3 inches                              *
*************************************************************************
wlp2 N=1 tpp3 0 outp 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'
wln2 N=1 tpn3 0 outn 0 fgd=8500meg RLGCmodel=model1_tl8 L='3*25.4mm'

*************************************************************************
* Load at Receiver							*
*************************************************************************
rpp	outp 0		50
rnn	outn 0		50

*************************************************************************
* Simulation Commands and Probe						*
*************************************************************************
.param datarate=5g per2='1/datarate' dtr=133p dtf=133p amp=600m tdelay=0

.tran	'per2/20' '128*per2+10n' start=10n

.probe tran ax = par('time-int(time/per2)*per2')

.probe v(vip) v(vin)	redrv_in=v(vip vin) 
.probe v(xredriver.xi0.xi0.xi0.eq_op) v(xredriver.xi0.xi0.xi0.eq_on) eq_ox=v(xredriver.xi0.xi0.xi0.eq_op,xredriver.xi0.xi0.xi0.eq_on) 
.probe v(xredriver.xi0.xi0.lmt_op) v(xredriver.xi0.xi0.lmt_on) lmt_ox=v(xredriver.xi0.xi0.lmt_op,xredriver.xi0.xi0.lmt_on)
.probe v(vop) v(von)	redrv_out=v(vop von)
.probe v(outp) v(outn) 	RX=v(outp outn)

.param requp=1e9 reqdn=1e-3 rdeup=1e9 rdedn=1e-3 $EQ=3dB, DE=0dB
.alter
.param requp=1e9 reqdn=1e9 rdeup=1e9 rdedn=1e-3 $EQ=6dB, DE=0dB
.alter
.param requp=1e-3 reqdn=1e9 rdeup=1e9 rdedn=1e-3  $EQ=9dB, DE=0dB
.alter
.param requp=1e9 reqdn=1e-3 rdeup=1e9 rdedn=1e9  $EQ=3dB, DE=-3.5dB
.alter
.param requp=1e9 reqdn=1e9 rdeup=1e-3 rdedn=1e9  $EQ=3dB, DE=-6dB
.end
